@@ -1,38 +1,26 @@
 /* vi: ts=8 sts=4 sw=4
- *
- * This file is part of the KDE project, module kdecore.
- * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
- *                    Antonio Larrosa <larrosa@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License version 2 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- */
+
+    This file is part of the KDE project, module kdecore.
+    SPDX-FileCopyrightText: 2000 Geert Jansen <jansen@kde.org>
+    SPDX-FileCopyrightText: 2000 Antonio Larrosa <larrosa@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 
 #ifndef KICONTHEME_H
 #define KICONTHEME_H
 
 #include <kiconthemes_export.h>
 
+#include <QList>
 #include <QString>
 #include <QStringList>
-#include <QList>
+
+#include <memory>
 
 #include "kiconloader.h"
 
 class QAction;
-class KIconThemeDir;
 
 /**
  * @internal
@@ -56,6 +44,9 @@ public:
     explicit KIconTheme(const QString &name, const QString &appName = QString(), const QString &basePathHint = QString());
     ~KIconTheme();
 
+    KIconTheme(const KIconTheme &) = delete;
+    KIconTheme &operator=(const KIconTheme &) = delete;
+
     /**
      * The stylized name of the icon theme.
      * @return the (human-readable) name of the theme
@@ -264,27 +255,8 @@ public:
      */
     static QString defaultThemeName();
 
-    /**
-     * Defines the context menus that assignIconsToContextMenus is
-     * aware of.
-     *
-     * For ReadOnlyText the menu is expected to have one entry.
-     *
-     * TextEditor is expected to have the full complement of
-     * undo, redo, cut, copy, paste and clear.
-     */
-    enum ContextMenus { TextEditor,
-                        ReadOnlyText
-                      };
-
-    /**
-     * Assigns standard icons to the various standard text edit context menus.
-     */
-    static void assignIconsToContextMenu(ContextMenus type, QList<QAction *> actions);
-
 private:
-    class KIconThemePrivate;
-    KIconThemePrivate *const d;
+    std::unique_ptr<class KIconThemePrivate> const d;
 };
 
 #endif
